# Automatically generated by ./create_defs.grib2.lte33.pl, do not edit
#Time-mean total cloud cover
'Time-mean total cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Carbon dioxide mass mixing ratio
'Carbon dioxide mass mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 3 ;
	 is_chemical = 1 ;
}
