# (C) Copyright 2005- ECMWF.

# Predefined grid 24

constant Ni = 37;
constant Nj = 37;

constant longitudeOfFirstGridPoint = -180000;
constant longitudeOfLastGridPoint = 0;

constant latitudeOfFirstGridPoint = -90000;
constant latitudeOfLastGridPoint = 0;

constant iDirectionIncrement = 5000;
constant jDirectionIncrement = 2500;

constant numberOfDataPoints=1369;
constant numberOfValues=1333 ;

