'IFS' = {
    backgroundProcess = 255;
}
'aifs-single' = {
    backgroundProcess = 1;
}
'aifs-ens' = {
    backgroundProcess = 2;
}
'aifs-single-mse' = {
    backgroundProcess = 3;
}
'aifs-ens-crps' = {
    backgroundProcess = 4;
}
'aifs-ens-diff' = {
    backgroundProcess = 5;
}
'aifs-compo-single' = {
    backgroundProcess = 6;
}
'aifs-compo-ens' = {
    backgroundProcess = 7;
}
'aifs-compo-single-mse' = {
    backgroundProcess = 8;
}
'aifs-compo-ens-crps' = {
    backgroundProcess = 9;
}
'unknown' = {
    true =defined(typeOfPostProcessing);
}
